@@ -22,17 +22,25 @@ yt_recoverable_errors = re.compile(
 .*HTTP Error 429
 .*HTTP Error 400
 .*HTTP Error 503: Service Unavailable
+.*Origin Error
+.*API is not granting access
 .*Did not get any data blocks
 .*Too Many Requests
+.*Postprocessing
 .*Premieres in
 .*read operation timed out
 .*Internal Server Error
 .*Internal error encountered
+.*Downloaded .* bytes, expected .* bytes
 .*Playlists that require authentication may not extract correctly without a successful webpage download
 .*Main webpage is locked behind the login page
 .*You need to log in to access this content
 .*This video is only available for registered users
+.*members-only content
+.*not available in your location
+.*This video is only available to Music Premium members
 .*episode is not currently available
+.*This channel has no uploads
 .*Could not send HEAD request
 .*Unable to download JSON metadata
 .*Failed to parse JSON Expecting
@@ -85,10 +93,11 @@ yt_meaningless_errors = re.compile(
 .*Finished downloading playlist
 .*The last 30x error message was:
 .*NoneType
+.*unable to download video data
+.*HTTP Error 405
 .*Creating a generic title instead
 .*The channel is not currently live
 .*clips are not currently supported.
-.*Join this channel to get access to members-only content
 .*Confirm you are on the latest version using
 .*referenced before assignment
 .*field is missing or empty
@@ -107,6 +116,7 @@ yt_meaningless_errors = re.compile(
 .*WARNING: unable to obtain file audio codec with ffprobe
 .*matching opening tag for closing p tag not found
 .*the JSON object must be str, bytes or bytearray, not dict
+.*list indices must be integers
 .*The read operation timed out
 .*Unable to recognize playlist.
 .*Premieres in""".splitlines()
@@ -119,11 +129,16 @@ yt_unrecoverable_errors = re.compile(
 .*It is not available
 .*has already been recorded in the archive
 .*ideo.*is private
+.*No video player ID
+.*has been removed
+.*from a suspended account
 .*This video has been disabled
 .*No suitable extractor
 .*The URL must be suitable for the extractor
 .*Private video
 .*not a video
+.*Invalid URL
+.*The given url does not contain a video
 .*because this account owner limits who can view
 .*No status found with that ID
 .*program functionality for this site has been marked as broken, and will probably not work
@@ -134,7 +149,8 @@ yt_unrecoverable_errors = re.compile(
 .*list index out of range
 .*Unable to extract cnn url
 .*PornHd.*Unable to extract error message
-.*members-only content
+.*status error-notFound
+.*ERROR.*'items'\$
 .*You don't have permission to access this video.
 .*Video is unavailable pending review
 .*Video has been flagged for verification
@@ -146,17 +162,19 @@ yt_unrecoverable_errors = re.compile(
 .*This video requires payment to watch.\$
 .*Unable to download webpage
 .*dashboard-only post
-.*This video is only available to Music Premium members
 .*The policy key provided does not permit this account or video
 .*live stream recording
 .*The channel is not currently live
 .*This live event will begin in a few moments
 .*nudity or sexual content
 .*policy on harassment and bullying
-.*stream.* is offline\$
+.*Can't find object userchannel
+.*is offline
 .*: Video unavailable\$
-.* does not exist.\$
-.* has been removed\$
+.*does not exist
+.*has been removed
+.*no video on the webpage
+.*Track not found
 .*: Not found.
 .*Video no longer exists
 .*Premieres in.*hours\$
@@ -179,6 +197,7 @@ yt_unrecoverable_errors = re.compile(
 .*not a video\$
 .*The page doesn't contain any tracks
 .*removed by the uploader
+.*Access to this video has been restricted by its creator
 .*blocked due to author's rights infingement
 .*blocked it on copyright grounds\$
 .*uploader has closed their.*account
@@ -192,6 +211,7 @@ yt_unrecoverable_errors = re.compile(
 .*Community Guidelines
 .*Terms of Service
 .*This channel does not exist
+.*account that no longer exists
 .*account associated with this video
 .*This video doesn't exist.\$
 .*Track not found\$
