@@ -41,7 +41,7 @@ def parse_args(action, usage):
     parser.add_argument("--ext", default="DEFAULT")
     parser.add_argument("--print", "-p", default=False, const="p", nargs="?", help=argparse.SUPPRESS)
     parser.add_argument("--cols", "-cols", "-col", nargs="*", help=argparse.SUPPRESS)
-    parser.add_argument("--sort", "-u", nargs="+", help=argparse.SUPPRESS)
+    parser.add_argument("--sort", "-u", nargs="+", default=["random"], help=argparse.SUPPRESS)
     parser.add_argument("--where", "-w", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
     parser.add_argument("--include", "-s", "--search", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
     parser.add_argument("--exclude", "-E", "-e", nargs="+", action="extend", default=[], help=argparse.SUPPRESS)
@@ -105,7 +105,7 @@ def construct_query(args) -> Tuple[str, dict]:
 
     cf.append(
         f"""and cast(STRFTIME('%s',
-          datetime( time_modified, 'unixepoch', '+{args.retry_delay}')
+          datetime( COALESCE(time_modified,0), 'unixepoch', '+{args.retry_delay}')
         ) as int) < STRFTIME('%s', datetime()) """
     )
 
@@ -134,15 +134,16 @@ def construct_query(args) -> Tuple[str, dict]:
         FROM media m
         LEFT JOIN playlists p on (p.path = m.playlist_path {"and p.ie_key != 'Local' and p.ie_key = m.ie_key" if 'ie_key' in m_columns else ''})
         WHERE 1=1
-            and (m.time_downloaded is null or m.time_downloaded=0)
-            and (m.time_deleted is null or m.time_deleted=0)
-            and (p.time_deleted is null or p.time_deleted=0)
+            and COALESCE(m.time_downloaded,0) = 0
+            and COALESCE(m.time_deleted,0) = 0
+            and COALESCE(p.time_deleted,0) = 0
+            and m.path like "http%"
             {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
             {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
             {args.sql_filter}
         ORDER BY 1=1
-            {', ' + args.sort if args.sort else ''}
             , play_count
+            {', ' + args.sort if args.sort else ''}
             , random()
     {LIMIT}
     """
@@ -230,7 +231,7 @@ def dl_download(args=None) -> None:
                 SELECT path from media
                 WHERE 1=1
                 AND (path=? or {'web' if 'webpath' in m_columns else ''}path=?)
-                {f'AND time_modified > {str(previous_time_attempted)}' if 'time_modified' in m_columns else ''}
+                {f'AND COALESCE(time_modified,0) > {str(previous_time_attempted)}' if 'time_modified' in m_columns else ''}
                 """,
                 [m["path"], m["path"]],
             )
