@@ -59,6 +59,7 @@ def usage(action) -> str:
         library {action} -p    # print in a table
         library {action} -p p  # equivalent
         library {action} -p a  # print an aggregate report
+        library {action} -p a  # print a bigdirs report (see lb bigdirs -h for more info)
         library {action} -p f  # print fields -- useful for piping paths to utilities like xargs or GNU Parallel
 
         Check if you have downloaded something before
@@ -75,7 +76,7 @@ def usage(action) -> str:
         ╘═══════════╧══════════════╧═════════╧═════════╛
         Total duration: 14 days, 23 hours and 42 minutes
 
-        Print an aggregate report of media that has no duration information (likely corrupt media)
+        Print an aggregate report of media that has no duration information (likely corrupt or online media)
         library {action} -w 'duration is null' -p=a
 
         Print a list of filenames which have below 1280px resolution
@@ -368,6 +369,11 @@ def parse_args(action, default_chromecast=None) -> argparse.Namespace:
     parser.add_argument("--local-media-only", "--local-only", action="store_true", help=argparse.SUPPRESS)
     parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
 
+    parser.add_argument("--sort-by-deleted", action="store_true")
+    parser.add_argument("--depth", "-D", default=0, type=int, help="Depth of folders")
+    parser.add_argument("--lower", type=int, help="Number of files per folder lower limit")
+    parser.add_argument("--upper", type=int, help="Number of files per folder upper limit")
+
     parser.add_argument("--timeout", "-T", help=argparse.SUPPRESS)
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
     parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true")
@@ -518,10 +524,10 @@ def construct_query(args) -> Tuple[str, dict]:
     WHERE 1=1
         {f'and path like "http%"' if args.safe else ''}
         {f'and path not like "{Path(args.keep_dir).resolve()}%"' if args.post_action == 'askkeep' else ''}
-        {'and time_deleted=0' if 'time_deleted' in m_columns and 'time_deleted' not in ' '.join(sys.argv) else ''}
+        {'and COALESCE(time_deleted,0) = 0' if 'time_deleted' in m_columns and 'time_deleted' not in ' '.join(sys.argv) else ''}
         {'AND (score IS NULL OR score > 7)' if 'score' in m_columns else ''}
         {'AND (upvote_ratio IS NULL OR upvote_ratio > 0.73)' if 'upvote_ratio' in m_columns else ''}
-        {'AND time_downloaded = 0' if args.online_media_only else ''}
+        {'AND COALESCE(time_downloaded,0) = 0' if args.online_media_only else ''}
         {'AND time_downloaded > 0 AND path not like "http%"' if args.local_media_only else ''}
     )
     SELECT
@@ -598,7 +604,10 @@ def play(args, m: Dict) -> None:
             media_file = transcode(media_file)
 
     if args.action == SC.listen and not media_file.startswith("http"):
-        print(cmd("ffprobe", "-hide_banner", "-loglevel", "info", media_file).stderr)
+        try:
+            print(cmd("ffprobe", "-hide_banner", "-loglevel", "info", media_file).stderr)
+        except UnicodeEncodeError:
+            print(media_file)
     else:
         print(media_file)
 
